Bifrost: UnitigColors::ColorKmer_ID Class Reference

Bifrost

Public Member Functions
UnitigColors::ColorKmer_ID Class Reference

Represents the position of a k-mer in a unitig and the ID of the color associated with the k-mer at the given position. More...

## Public Member Functions
size_t | getColorID (const size_t length_unitig_km) const
| Get the color ID. More...
size_t | getKmerPosition (const size_t length_unitig_km) const
| Get the k-mer position (on the forward strand of the unitig). More...

## Detailed Description

Represents the position of a k-mer in a unitig and the ID of the color associated with the k-mer at the given position.

## Member Function Documentation

## ◆ getColorID()

size_t UnitigColors::ColorKmer_ID::getColorID | ( | const size_t | length_unitig_km | ) | const
| inline

Get the color ID.

Parameters

  length_unitig_km | is the length of the unitig (in k-mers) associated with the UnitigColors object this ColorKmer_ID object refers to.

Returns
  a color ID;

## ◆ getKmerPosition()

size_t UnitigColors::ColorKmer_ID::getKmerPosition | ( | const size_t | length_unitig_km | ) | const
| inline

Get the k-mer position (on the forward strand of the unitig).

Parameters

  length_unitig_km | is the length of the unitig (in k-mers) associated with the UnitigColors object this ColorKmer_ID object refers to.

Returns
  a k-mer position;

The documentation for this class was generated from the following file:

- src/ColorSet.hpp